@@ -1,4 +1,4 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, you can obtain one at http://mozilla.org/MPL/2.0/.
-default_app_config = 'dockerflow.django.apps.DockerFlowAppConfig'
+default_app_config = "dockerflow.django.apps.DockerFlowAppConfig"
